@@ -1,6 +1,6 @@
 use crate::WSClient;
 use std::collections::HashMap;
-use std::sync::{Arc, Mutex};
+use std::sync::mpsc::Sender;
 
 use super::{
     utils::CHANNEL_PAIR_DELIMITER,
@@ -23,8 +23,8 @@ const CLIENT_PING_INTERVAL_AND_MSG: (u64, &str) = (60, r#"{"cmd":"ping"}"#);
 ///
 ///   * WebSocket API doc: <https://github.com/bithumb-pro/bithumb.pro-official-api-docs/blob/master/ws-api.md>
 ///   * Trading at: <https://en.bithumb.com/trade/order/BTC_KRW>
-pub struct BithumbWSClient<'a> {
-    client: WSClientInternal<'a>,
+pub struct BithumbWSClient {
+    client: WSClientInternal,
 }
 
 fn channels_to_commands(channels: &[String], subscribe: bool) -> Vec<String> {
@@ -89,19 +89,19 @@ impl_trait!(Ticker, BithumbWSClient, subscribe_ticker, "TICKER", to_raw_channel)
 #[rustfmt::skip]
 impl_trait!(OrderBook, BithumbWSClient, subscribe_orderbook, "ORDERBOOK", to_raw_channel);
 
-impl<'a> BBO for BithumbWSClient<'a> {
+impl BBO for BithumbWSClient {
     fn subscribe_bbo(&self, _pairs: &[String]) {
         panic!("bithumb WebSocket does NOT have BBO channel");
     }
 }
 
-impl<'a> OrderBookTopK for BithumbWSClient<'a> {
+impl OrderBookTopK for BithumbWSClient {
     fn subscribe_orderbook_topk(&self, _pairs: &[String]) {
         panic!("bithumb does NOT have orderbook snapshot channel");
     }
 }
 
-impl<'a> Candlestick for BithumbWSClient<'a> {
+impl Candlestick for BithumbWSClient {
     fn subscribe_candlestick(&self, _symbol_interval_list: &[(String, usize)]) {
         panic!("bithumb does NOT have candlestick channel");
     }
