@@ -1,5 +1,5 @@
 use crate::WSClient;
-use std::sync::{Arc, Mutex};
+use std::sync::mpsc::Sender;
 
 use super::super::ws_client_internal::WSClientInternal;
 use super::super::{Candlestick, Level3OrderBook, OrderBook, OrderBookTopK, Ticker, Trade, BBO};
@@ -19,8 +19,8 @@ lazy_static! {
 ///
 /// * WebSocket API doc: <https://docs.kucoin.cc/futures/#websocket-2>
 /// * Trading at: <https://futures.kucoin.com/>
-pub struct KuCoinSwapWSClient<'a> {
-    client: WSClientInternal<'a>,
+pub struct KuCoinSwapWSClient {
+    client: WSClientInternal,
 }
 
 #[rustfmt::skip]
@@ -55,7 +55,7 @@ fn to_candlestick_raw_channel(pair: &str, interval: usize) -> String {
 
 impl_candlestick!(KuCoinSwapWSClient);
 
-impl<'a> Level3OrderBook for KuCoinSwapWSClient<'a> {
+impl Level3OrderBook for KuCoinSwapWSClient {
     fn subscribe_l3_orderbook(&self, symbols: &[String]) {
         let raw_channels: Vec<String> = symbols
             .iter()
